#!/bin/bash

# Release font samples in WWW.

# Author:
# Juhapekka Tolvanen
# http://iki.fi/juhtolv
# juhtolv (at) iki (dot) fi

# This script is public domain. There is no warranty.

# Some (l)user-serviceable environment variables are in that file
# called fontsamples.rc.sh

if . ./fontsamples.rc.sh
then
    :
else
    echo "./fontsamples.rc.sh could not be read" 
    exit 1
fi

cd ${WORKDIR} || exit 1
rm -f release_docs_starttime.txt
date '+%s' > release_docs_starttime.txt

if . ./checkworkdirs.sh
then
    :
else
    echo "./checkworkdirs.sh could not be read" 
    exit 1
fi

if . ./checkwwwdirs.sh
then
    :
else
    echo "./checkwwwdirs.sh could not be read" 
    exit 1
fi


CHARMAP="`locale charmap`"

if test "$CHARMAP" == "UTF-8"
then
    echo "Your environment is UTF-8-safe"
else
    echo "Your environment is not UTF-8-safe"
    exit 1
fi

###############################################################################
# Every LaTeX-file should be created and compiled, already, when you run this
# script. Let’s put everything to WWW-directories:

for f in ${WWWDIR} ${WWWDIRTWO}
do

    mkdir -p ${f}/juhtolv-fontsamples-scripts 2> /dev/null
    rm -f ${f}/juhtolv-fontsamples-scripts/* 2> /dev/null

    cd ${WORKDIR} || exit 1

    for g in tex pdf ps
    do
        cp -f 000README.${g} ${f}/
        cp -f 000README.${g} ${f}/juhtolv-fontsamples-scripts/
    done

    cp -f \
    checkworkdirs.sh \
    checkwwwdirs.sh \
    cleanall.sh \
    compiledocs.sh \
    compile_subgroup.sh \
    compress_subgroup.sh \
    createtexfile_kanji.sh \
    createtexfile_kanji_unihan.sh \
    createtexfile.sh \
    doallbutrelease_files.sh \
    doallbutrelease_subgroup.sh \
    doall_files.sh \
    doall_subgroup.sh \
    fontsamples_bottom.tex \
    fontsamples_end.tex \
    fontsamples_end_kanji.tex \
    fontsamples.rc.sh \
    fontsamples_start.tex \
    fontsamples_start_kanji_A.tex \
    fontsamples_start_kanji_B.tex \
    fontsamples_top.tex \
    fontsamples_top_kanji.tex \
    getdics.sh \
    mydate.sh \
    progress_status.sh \
    purgeall.sh \
    purgedocs.sh \
    rc.hiragana_basic.sh \
    rc.hiragana_dakuon.sh \
    rc.hiragana_handakuon.sh \
    rc.hiragana_other.sh \
    rc.hiragana_yoo-on.sh \
    rc.kanji_G1.sh \
    rc.kanji_G2.sh \
    rc.kanji_G3.sh \
    rc.kanji_G4.sh \
    rc.kanji_G5.sh \
    rc.kanji_G6.sh \
    rc.kanji_G8.sh \
    rc.kanji_G9.sh \
    rc.kanji_G10.sh \
    rc.kanji_other-common.sh \
    rc.kanji_other-uncommon1.sh \
    rc.kanji_other-uncommon2.sh \
    rc.kanji_other-uncommon3.sh \
    rc.kanji_other-uncommon4.sh \
    rc.katakana_ainu.sh \
    rc.katakana_basic.sh \
    rc.katakana_circled.sh \
    rc.katakana_dakuon.sh \
    rc.katakana_halfwidth.sh \
    rc.katakana_handakuon.sh \
    rc.katakana_other.sh \
    rc.katakana_yoo-on.sh \
    release_docs.sh \
    release_subgroup.sh \
    taunt.sh \
    tree.pl \
    tree-template.html \
    ${f}/juhtolv-fontsamples-scripts/

    cat taunt.sh >> ${f}/juhtolv-fontsamples-scripts/fontsamples.rc.sh

    chmod -R u+rwX,go+rX,go-w ${f}/
    chmod -R ugo-x,ugo+r,go-w ${f}/juhtolv-fontsamples-scripts/*
    chmod -R ugo-x,ugo+r,go-w ${f}/juhtolv-fontsamples-du_files/*
    chmod -R ugo-x,ugo+r,go-w ${f}/juhtolv-fontsamples-index/* 
    chmod -R ugo-x,ugo+r,go-w ${f}/000README.*
done


#############################################################################
# Let’s start packing

# Let’s pack docs, index and scripts:

for f in ${WWWDIR} ${WWWDIRTWO}
do
    chmod ugo-x,ugo+r,go-w ${f}/000README.*
    rm -fv ${f}/000README.tex.bz2 ${f}/000README.tex.7z 2> /dev/null
    $SEVENZIP_BIN a $SEVENZIPOPTSTWO ${f}/000README.tex.7z ${f}/000README.tex
    rm -fv ${f}/000README.tex 2> /dev/null

    rm -fv ${f}/000README.ps.bz2 2> /dev/null
    bzip2 -9v ${f}/000README.ps

    rm -fv ${f}/000README.pdf.bz2 2> /dev/null
    bzip2 -9kv ${f}/000README.pdf

    chmod ugo-x,ugo+r,go-w ${f}/000README.*

    chmod ugo+rx ${f}/juhtolv-fontsamples-scripts
    chmod ugo-x,ugo+r,go-w ${f}/juhtolv-fontsamples-scripts/*

    rm -fv ${f}/juhtolv-fontsamples-scripts.tar.bz2  ${f}/juhtolv-fontsamples-scripts.7z 2> /dev/null
    cd ${f}/ || exit 1
    echo "$SEVENZIP_BIN a $SEVENZIPOPTSTWO juhtolv-fontsamples-scripts.7z juhtolv-fontsamples-scripts"
    $SEVENZIP_BIN a $SEVENZIPOPTSTWO juhtolv-fontsamples-scripts.7z juhtolv-fontsamples-scripts
    rm -rf ${f}/juhtolv-fontsamples-scripts

    chmod -R u+rwX,go+rX,go-w ${f}
done


cd ${WORKDIR}

rm -f ${WWWDIRTWO}/index.html
./tree.pl ${WWWDIRTWO} > ${WWWDIRTWO}/index.html
chmod ugo+r,go-w,ugo-x ${WWWDIRTWO}/index.html

rm -f release_docs_endtime.txt
date '+%s' > release_docs_endtime.txt

# -*- coding: utf-8 -*-

# Local Variables: ***
# mode:Shell-script ***
# coding: utf-8 ***
# End: ***

# vim: set ft=sh fenc=utf-8 :

